@@ -2,7 +2,8 @@ from sqlglot.dialects import Dialect
 from sqlglot.errors import ErrorLevel, UnsupportedError, ParseError, TokenError
 from sqlglot.expressions import (
     Expression,
-    Select,
+    select,
+    from_,
     and_,
     or_,
     not_,
@@ -15,7 +16,7 @@ from sqlglot.tokens import Tokenizer, TokenType
 from sqlglot.parser import Parser
 
 
-__version__ = "2.7.0"
+__version__ = "3.0.0"
 
 pretty = False
 
@@ -89,47 +90,3 @@ def transpile(sql, read=None, write=None, identity=True, error_level=None, **opt
         Dialect.get_or_raise(write)().generate(expression, **opts)
         for expression in parse(sql, read, error_level=error_level)
     ]
-
-
-def select(*expressions, dialect=None, **opts):
-    """
-    Initializes a syntax tree from one or multiple SELECT expressions.
-
-    Example:
-        >>> select("col1", "col2").from_("tbl").sql()
-        'SELECT col1, col2 FROM tbl'
-
-    Args:
-        *expressions (str or Expression): the SQL code string to parse as the expressions of a
-            SELECT statement. If an Expression instance is passed, this is used as-is.
-        dialect (str): the dialect used to parse the input expressions (in the case that an
-            input expression is a SQL string).
-        **opts: other options to use to parse the input expressions (again, in the case
-            that an input expression is a SQL string).
-
-    Returns:
-        Select: the syntax tree for the SELECT statement.
-    """
-    return Select().select(*expressions, dialect=dialect, parser_opts=opts)
-
-
-def from_(*expressions, dialect=None, **opts):
-    """
-    Initializes a syntax tree from a FROM expression.
-
-    Example:
-        >>> from_("tbl").select("col1", "col2").sql()
-        'SELECT col1, col2 FROM tbl'
-
-    Args:
-        *expressions (str or Expression): the SQL code string to parse as the FROM expressions of a
-            SELECT statement. If an Expression instance is passed, this is used as-is.
-        dialect (str): the dialect used to parse the input expression (in the case that the
-            input expression is a SQL string).
-        **opts: other options to use to parse the input expressions (again, in the case
-            that the input expression is a SQL string).
-
-    Returns:
-        Select: the syntax tree for the SELECT statement.
-    """
-    return Select().from_(*expressions, dialect=dialect, parser_opts=opts)
