@@ -29,7 +29,7 @@ def pushdown_projections(expression):
     # We build the scope tree (which is traversed in DFS postorder), then iterate
     # over the result in reverse order. This should ensure that the set of selected
     # columns for a particular scope are completely build by the time we get to it.
-    for scope in reversed(list(traverse_scope(expression))):
+    for scope in reversed(traverse_scope(expression)):
         parent_selections = referenced_columns.get(scope, {SELECT_ALL})
 
         if scope.expression.args.get("distinct"):
@@ -47,12 +47,12 @@ def pushdown_projections(expression):
             # Group columns by source name
             selects = defaultdict(set)
             for col in scope.columns:
-                table_name = col.text("table")
-                col_name = col.text("this")
+                table_name = col.table
+                col_name = col.name
                 selects[table_name].add(col_name)
 
             # Push the selected columns down to the next scope
-            for name, source in scope.selected_sources.items():
+            for name, (_, source) in scope.selected_sources.items():
                 if isinstance(source, Scope):
                     columns = selects.get(name) or set()
                     referenced_columns[source].update(columns)
