@@ -76,8 +76,8 @@ def _qualify_columns(scope, schema):
     unambiguous_columns = None  # lazily loaded
 
     for column in scope.columns:
-        column_table = column.text("table")
-        column_name = column.text("this")
+        column_table = column.table
+        column_name = column.name
 
         if (
             column_table
@@ -111,7 +111,7 @@ def _expand_stars(scope, schema):
         elif isinstance(expression, exp.Column) and isinstance(
             expression.this, exp.Star
         ):
-            tables = [expression.text("table")]
+            tables = [expression.table]
         else:
             continue
 
@@ -122,11 +122,7 @@ def _expand_stars(scope, schema):
                 raise OptimizeError(f"Unknown table: {table}")
             columns = _get_source_columns(table, scope.sources, schema)
             for column in columns:
-                new_columns.append(
-                    exp.Column(
-                        this=exp.to_identifier(column), table=exp.to_identifier(table)
-                    )
-                )
+                new_columns.append(exp.column(column, table))
 
         expression.replace(*new_columns)
 
@@ -138,15 +134,16 @@ def _qualify_outputs(scope):
         itertools.zip_longest(scope.selects, scope.outer_column_list)
     ):
         if isinstance(selection, exp.Column):
-            selection_name = selection.text("this")
-            new_selection = exp.alias_(selection.copy(), selection_name)
-            selection.replace(new_selection)
-            selection = new_selection
+            # convoluted setter because a simple selection.replace(alias) would require a copy
+            alias = exp.alias_(exp.column(""), selection.name)
+            selection.replace(alias)
+            alias.set("this", selection)
+            selection = alias
         elif not isinstance(selection, exp.Alias):
-            selection_name = f"_col_{i}"
-            new_selection = exp.alias_(selection.copy(), selection_name)
-            selection.replace(new_selection)
-            selection = new_selection
+            alias = exp.alias_(exp.column(""), f"_col_{i}")
+            selection.replace(alias)
+            alias.set("this", selection)
+            selection = alias
 
         if aliased_column:
             selection.set("alias", exp.to_identifier(aliased_column))
